<?php
/**
 * FSF Member Dashboard
 * Copyright © 2014 Free Software Foundation, Inc.
 *
 * This file is a part of FSF Member Dashboard.
 *
 * FSF Member Dashboard is free software; you can copy, modify, and
 * distribute it under the terms of the GNU Affero General Public
 * License Version 3, 19 November 2007 and the CiviCRM Licensing
 * Exception.
 *
 * FSF Member Dashboard is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FSF Member Dashboard.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

require_once 'CRM/Core/Page.php';

class CRM_Memberdashboard_Page_Communications extends CRM_Memberdashboard_Page {
  function getGroups() {
    // Get all public groups.
    $allGroups = CRM_Core_PseudoConstant::staticGroup(true);

    // Arrange groups into hierarchical listing (child groups follow
    // their parents and have indentation spacing in title)
    $groupHierarchy = CRM_Contact_BAO_Group::getGroupsHierarchy($allGroups,
                                                                NULL,
                                                                '&nbsp;&nbsp;',
                                                                TRUE);

    // Get the list of groups contact is currently in ("Added") or
    // unsubscribed ("Removed").
    $id = $this->contact['id'];
    $currentGroups = CRM_Contact_BAO_GroupContact::getGroupList($id);

    // Remove groups that the user is already subscribed to.
    return array_diff_key($groupHierarchy, $currentGroups);
  }

  function postProcess($params) {
    // Update member's preferred mail format (plain text, HTML)
    civicrm_api3('contact', 'create', array(
      'id' => $this->contact['id'],
      'preferred_mail_format' => $params['preferred_mail_format']
    ));

    // Subscribe to a new group (if present)
    if(array_key_exists('group_id', $params) && $params['group_id'] != '') {
      $groupID = $params['group_id'];
      $contactID = array($this->contact['id']);
      $method = 'Web';
      $groupContact = CRM_Contact_BAO_GroupContact::addContactsToGroup($contactID,
                                                                       $groupID,
                                                                       $method);

      if($groupContact) {
        $groups = CRM_Core_PseudoConstant::group();
        CRM_Core_Session::setStatus(ts("Contact has been added to '%1'.",
                                       array(1 => $groups[$groupID])),
                                    ts('Added to Group'), 'success');
      }
    }
  }

  function run() {
    // Handle POST requests to update email preferences.
    if($this->isPOST()) {
      $this->postProcess($_POST);
    }

    $helper = new CRM_Memberdashboard_Page_ComponentHelper(array('CiviEvent'));
    $helper->run();
    $this->assign('dashboardElements', $helper->buildDashboardElements());

    $gContact = new CRM_Contact_Page_View_UserDashBoard_GroupContact();
    // Call browse instead of run in order to prevent additional form
    // elements appearing on the page that don't play nice with the rest
    // of the page.  This group subscription stuff is a big hack.
    $gContact->browse();

    $groups = array('' => ts('Select a group')) + $this->getGroups();

    $this->assign('contact', $this->contact);
    $this->assign('groups', $groups);
    $this->assign('mailFormats', array('Both', 'HTML', 'Text'));

    CRM_Utils_System::setTitle('Communications');

    parent::run();
  }
}
